LegacyOutlineButton class

Similar to a FlatButton with a thin grey rounded rectangle border.

Inheritance

Constructors

LegacyOutlineButton({Key? key, required VoidCallback? onPressed, VoidCallback? onLongPress, MouseCursor? mouseCursor, ButtonTextTheme? textTheme, Color? textColor, Color? disabledTextColor, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, double? highlightElevation, BorderSide? borderSide, Color? disabledBorderColor, Color? highlightedBorderColor, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, ShapeBorder? shape, Clip clipBehavior = Clip.none, FocusNode? focusNode, bool autofocus = false, MaterialTapTargetSize? materialTapTargetSize, Widget? child})
Create an outline button.
const
LegacyOutlineButton.icon({Key? key, required VoidCallback? onPressed, VoidCallback? onLongPress, MouseCursor? mouseCursor, ButtonTextTheme? textTheme, Color? textColor, Color? disabledTextColor, Color? color, Color? focusColor, Color? hoverColor, Color? highlightColor, Color? splashColor, double? highlightElevation, Color? highlightedBorderColor, Color? disabledBorderColor, BorderSide? borderSide, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, ShapeBorder? shape, Clip clipBehavior, FocusNode? focusNode, bool autofocus, MaterialTapTargetSize? materialTapTargetSize, required Widget icon, required Widget label})
Create an outline button from a pair of widgets that serve as the button's icon and label.
factory

Properties

animationDuration → Duration?
Defines the duration of animated changes for shape and elevation.
finalinherited
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
borderSide → BorderSide?
Defines the color of the border when the button is enabled but not pressed, and the border outline's width and style in general.
final
child → Widget?
The button's label.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
finalinherited
color → Color?
The button's fill color, displayed by its Material, while it is in its default (unpressed, enabled) state.
finalinherited
colorBrightness → Brightness?
The theme brightness to use for this button.
finalinherited
disabledBorderColor → Color?
The outline border's color when the button is not enabled.
final
disabledColor → Color?
The fill color of the button when the button is disabled.
finalinherited
disabledElevation → double?
The elevation for the button's Material relative to its parent when the button is not enabled.
finalinherited
disabledTextColor → Color?
The color to use for this button's text when the button is disabled.
finalinherited
elevation → double?
The z-coordinate at which to place this button relative to its parent.
finalinherited
enabled → bool
Whether the button is enabled or disabled.
no setterinherited
enableFeedback → bool
Whether detected gestures should provide acoustic and/or haptic feedback.
finalinherited
focusColor → Color?
The fill color of the button's Material when it has the input focus.
finalinherited
focusElevation → double?
The elevation for the button's Material when the button is enabled and has the input focus.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The vertical extent of the button.
finalinherited
highlightColor → Color?
The highlight color of the button's InkWell.
finalinherited
highlightedBorderColor → Color?
The outline border's color when the button is enabled and pressed.
final
highlightElevation → double?
The elevation for the button's Material relative to its parent when the button is enabled and pressed.
finalinherited
hoverColor → Color?
The fill color of the button's Material when a pointer is hovering over it.
finalinherited
hoverElevation → double?
The elevation for the button's Material when the button is enabled and a pointer is hovering over it.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize → MaterialTapTargetSize?
Configures the minimum size of the tap target.
finalinherited
minWidth → double?
The smallest horizontal extent that the button will occupy.
finalinherited
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the button.
finalinherited
onHighlightChanged → ValueChanged<bool>?
Called by the underlying InkWell widget's InkWell.onHighlightChanged callback.
finalinherited
onLongPress → VoidCallback?
The callback that is called when the button is long-pressed.
finalinherited
onPressed → VoidCallback?
The callback that is called when the button is tapped or otherwise activated.
finalinherited
padding → EdgeInsetsGeometry?
The internal padding for the button's child.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
The shape of the button's Material.
finalinherited
splashColor → Color?
The splash color of the button's InkWell.
finalinherited
textColor → Color?
The color to use for this button's text.
finalinherited
textTheme → ButtonTextTheme?
Defines the button's base colors, and the defaults for the button's minimum size, internal padding, and shape.
finalinherited
visualDensity → VisualDensity?
Defines how compact the button's layout will be.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited